==> dl.php?src=linea21_1_6.zip: linea21/library/scripts/languages/nl.js <==
{
    "ALLOWED_FILE_TYPE": "Only following files are allowed : ", 
    "AUTHORIZATION_REQUIRED": "Je hebt niet de nodige rechten om filemanager te gebruiken.", 
    "DIRECTORY_ALREADY_EXISTS": "De map '%s' bestaat al.", 
    "DIRECTORY_NOT_EXIST": "De map %s bestaat niet.", 
    "DISALLOWED_FILE_TYPE": "Following files are not allowed : ", 
    "ERROR_RENAMING_DIRECTORY": "Fout bij het hernoemen van de map %s naar %s.", 
    "ERROR_RENAMING_FILE": "Fout bij het hernoemen van het bestand %s naar %s.", 
    "FILE_ALREADY_EXISTS": "The file '%s' already exists.", 
    "FILE_DOES_NOT_EXIST": "Het bestand %s bestaat niet.", 
    "INVALID_ACTION": "Ongeldige actie.", 
    "INVALID_DIRECTORY_OR_FILE": "Ongeldige map of bestand.", 
    "INVALID_FILE_TYPE": "File upload is not allowed.", 
    "INVALID_FILE_UPLOAD": "Ongeldige bestandsupload.", 
    "INVALID_VAR": "Ongeldige variabele %s.", 
    "LANGUAGE_FILE_NOT_FOUND": "Het taalbestand is niet gevonden.", 
    "MODE_ERROR": "Mode fout.", 
    "UNABLE_TO_CREATE_DIRECTORY": "De map %s kon niet worden aangemaakt.", 
    "UNABLE_TO_OPEN_DIRECTORY": "De map %s kon niet worden geopend.", 
    "UPLOAD_FILES_SMALLER_THAN": "Upload alleen bestanden kleiner dan %s a.u.b.", 
    "UPLOAD_IMAGES_ONLY": "Alleen het uploaden van afbeeldingen is toegestaan.", 
    "UPLOAD_IMAGES_TYPE_JPEG_GIF_PNG": "Alleen het uploaden van afbeeldingen van het type JPEG, GIF of PNG is toegestaan.", 
    "browse": "Browse...", 
    "bytes": " bytes", 
    "cancel": "Annuleren", 
    "confirmation_delete": "Weet je zeker dat je dit bestand wilt verwijderen?", 
    "could_not_retrieve_folder": "Could not retrieve folder contents.", 
    "create_folder": "Nieuwe Map", 
    "created": "Gemaakt", 
    "current_folder": "Huidige map: ", 
    "default_foldername": "Mijn map", 
    "del": "Verwijderen", 
    "dimensions": "Formaat", 
    "download": "Downloaden", 
    "fck_select_integration": "De 'selecteer' functie is alleen voor integratie met CKEditor.", 
    "file_size_limit": "The file size limit is : ", 
    "file_too_big": "The file is too big.", 
    "gb": "gb", 
    "grid_view": "Pictogrammen", 
    "kb": "kb", 
    "list_view": "Lijst", 
    "loading_data": "Transferring data ...", 
    "mb": "mb", 
    "modified": "Gewijzigd", 
    "name": "Naam", 
    "new_filename": "Vul een nieuwe naam in voor het bestand", 
    "new_folder": "Nieuwe map", 
    "no": "Nee", 
    "no_foldername": "Je dient een naam te geven aan deze map.", 
    "parentfolder": "Terug naar bestanden", 
    "prompt_foldername": "Vul de nieuwe mapnaam in", 
    "rename": "Naam wijzigen", 
    "search": "Search", 
    "search_reset": "Reset", 
    "select": "Selecteren", 
    "select_from_left": "Selecteer een item aan de linker kant.", 
    "size": "Grootte", 
    "successful_added_file": "Het nieuwe bestand is toegevoegd.", 
    "successful_added_folder": "De nieuwe map is toegevoegd.", 
    "successful_delete": "Het bestand is verwijderd.", 
    "successful_rename": "De naam is gewijzigd.", 
    "upload": "Upload", 
    "yes": "Ja"
}

==> dl.php?src=linea21_1_7.zip: linea21/library/scripts/languages/nl.js <==
{
    "ALLOWED_FILE_TYPE": "De volgende bestandtypes zijn toegestaan : ", 
    "AUTHORIZATION_REQUIRED": "Je hebt niet de nodige rechten om filemanager te gebruiken.", 
    "DIRECTORY_ALREADY_EXISTS": "De map '%s' bestaat al.", 
    "DIRECTORY_NOT_EXIST": "De map %s bestaat niet.", 
    "DISALLOWED_FILE_TYPE": "De volgende bestandtypes zijn niet toegestaan : ", 
    "ERROR_RENAMING_DIRECTORY": "Fout bij het hernoemen van de map %s naar %s.", 
    "ERROR_RENAMING_FILE": "Fout bij het hernoemen van het bestand %s naar %s.", 
    "FILE_ALREADY_EXISTS": "Het bestand '%s' bestaat al.", 
    "FILE_DOES_NOT_EXIST": "Het bestand %s bestaat niet.", 
    "INVALID_ACTION": "Ongeldige actie.", 
    "INVALID_DIRECTORY_OR_FILE": "Ongeldige map of bestand.", 
    "INVALID_FILE_TYPE": "Het uploaden van bestanden is niet togestaan.", 
    "INVALID_FILE_UPLOAD": "Ongeldige bestandsupload.", 
    "INVALID_VAR": "Ongeldige variabele %s.", 
    "LANGUAGE_FILE_NOT_FOUND": "Het taalbestand is niet gevonden.", 
    "MODE_ERROR": "Mode fout.", 
    "UNABLE_TO_CREATE_DIRECTORY": "De map %s kon niet worden aangemaakt.", 
    "UNABLE_TO_OPEN_DIRECTORY": "De map %s kon niet worden geopend.", 
    "UPLOAD_FILES_SMALLER_THAN": "Upload alleen bestanden kleiner dan %s a.u.b.", 
    "UPLOAD_IMAGES_ONLY": "Alleen het uploaden van afbeeldingen is toegestaan.", 
    "UPLOAD_IMAGES_TYPE_JPEG_GIF_PNG": "Alleen het uploaden van afbeeldingen van het type JPEG, GIF of PNG is toegestaan.", 
    "browse": "Bladeren...", 
    "bytes": " bytes", 
    "cancel": "Annuleren", 
    "confirmation_delete": "Weet je zeker dat je dit bestand wilt verwijderen?", 
    "could_not_retrieve_folder": "Kon map-inhoud niet ophalen.", 
    "create_folder": "Nieuwe Map", 
    "created": "Gemaakt", 
    "current_folder": "Huidige map: ", 
    "default_foldername": "Mijn map", 
    "del": "Verwijderen", 
    "dimensions": "Formaat", 
    "download": "Downloaden", 
    "fck_select_integration": "De 'selecteer' functie is alleen voor integratie met CKEditor.", 
    "file_size_limit": "Het bestandslimiet is : ", 
    "file_too_big": "Het bestand is te groot.", 
    "gb": "gb", 
    "grid_view": "Pictogrammen", 
    "kb": "kb", 
    "list_view": "Lijst", 
    "loading_data": "Uploaden ...", 
    "mb": "mb", 
    "modified": "Gewijzigd", 
    "name": "Naam", 
    "new_filename": "Vul een nieuwe naam in voor het bestand", 
    "new_folder": "Nieuw", 
    "no": "Nee", 
    "no_foldername": "Je dient een naam te geven aan deze map.", 
    "parentfolder": "Terug naar bestanden", 
    "prompt_foldername": "Vul de nieuwe mapnaam in", 
    "rename": "Naam wijzigen", 
    "search": "Zoeken", 
    "search_reset": "Reset", 
    "select": "Selecteren", 
    "select_from_left": "Selecteer een item aan de linker kant.", 
    "size": "Grootte", 
    "successful_added_file": "Het nieuwe bestand is toegevoegd.", 
    "successful_added_folder": "De nieuwe map is toegevoegd.", 
    "successful_delete": "Het bestand is verwijderd.", 
    "successful_rename": "De naam is gewijzigd.", 
    "upload": "Upload", 
    "yes": "Ja"
}
